@@ -25,11 +25,13 @@ function(libname, pkgname)
  #    library(REventLoop)
  #    eventLoop(REventLoop("R_Gtk2EventLoop"))
  #    runEventLoop()
- #} else 
- if(!(gtkInit(args))) {
-   message("R session is headless; GTK+ not initialized.")
-   if (length(grep("darwin", R.version$platform)))
-     message("Please try running R inside an X11 terminal.")
+ #} else
+ if (interactive()) {
+   if(!(gtkInit(args))) {
+     message("R session is headless; GTK+ not initialized.")
+     if (length(grep("darwin", R.version$platform)))
+       message("Please try running R inside an X11 terminal.")
+   }
  }
 }
 
